Module sqlite_rs::io

source ·

Structs

Enums

  • The mode query parameter determines if the new database is opened read-only, read-write, read-write and created if it does not exist, or that the database is a pure in-memory database that never interacts with disk, respectively.