SqliteUriFileMode

Enum SqliteUriFileMode 

pub enum SqliteUriFileMode {
    ReadOnly,
    ReadWrite,
    ReadWriteCreate,
}
The mode query parameter determines if the new database is opened read-only, read-write, read-write and created if it does not exist, or that the database is a pure in-memory database that never interacts with disk, respectively.

Reference: https://www.sqlite.org/uri.html#urimode

Variants



ReadOnly



ReadWrite



ReadWriteCreate